Signature

Enum Signature 

pub enum Signature {
    Md5(Md5),
    Sha1(Sha1),
    Sha256(Sha256),
    Sha512(Sha512),
}
A possible phar signature

Variants



Md5(Md5)

Available on crate feature sig-md5 only.

Signature corresponding to Phar::MD5



Sha1(Sha1)

Available on crate feature sig-sha1 only.

Signature corresponding to Phar::SHA1



Sha256(Sha256)

Available on crate feature sig-sha2 only.

Signature corresponding to Phar::SHA256



Sha512(Sha512)

Available on crate feature sig-sha2 only.

Signature corresponding to Phar::SHA512

Implementations

Source

impl Signature

pub fn md5() -> Self

Available on crate feature sig-md5 only.

Creates an md5 signature

pub fn sha1() -> Self

Available on crate feature sig-sha1 only.

Creates a sha1 signature

pub fn sha256() -> Self

Available on crate feature sig-sha2 only.

Creates a sha256 signature

pub fn sha512() -> Self

Available on crate feature sig-sha2 only.

Creates a sha512 signature

pub fn from_u32(discrim: u32) -> Option<Self>

Creates a signature from the phar format flag

pub fn to_u32(&self) -> u32

Returns the phar format flag of the signature type

pub fn size(&self) -> u8

The number of bytes used for this signature

pub fn write(&mut self) -> impl Write + '_

Returns a Write that writes to the underlying digest

pub fn finalize(self) -> SmallVec<[u8; 64]>

Returns the memory allocated by the underlying signature implementation