OffsetOnly

Struct OffsetOnly 

pub struct OffsetOnly { /* private fields */ }
Available on crate feature reader only.
Stores files by position.

Uses only O(nm) memory, where n is the number of files, and m is either 1 or the length of filenames depending on whether files are cached.