NeedAlias

Struct NeedAlias 

pub struct NeedAlias<W: Read + Write + Seek> { /* private fields */ }
Available on crate feature writer only.
Intermediate type for writing phar.

Call alias or metadata to progress to the next builder step.

Implementations

Source

impl<W: Read + Write + Seek> NeedAlias<W>

pub fn alias(self, alias: impl Read) -> Result<NeedGlobMeta<W>>

Sets the alias for the phar archive.

pub fn metadata(self, metadata: impl Read) -> Result<NeedEntries<W>>

Sets the metadata for the phar archive.

The phar crate does not validate the contents, but they should either be empty string or comply to PHP serialization format.