NeedEntries

Struct NeedEntries 

pub struct NeedEntries<W: Read + Write + Seek> { /* private fields */ }
Available on crate feature writer only.
Preparation step for writing phar entries.

For performance reasons, users need to first provide all file metadata before providing all file contents. Consider using build_from_* if the data source is located on the filesystem.

Implementations

Source

impl<W: Read + Write + Seek> NeedEntries<W>

pub fn entry( &mut self, name: impl Read, metadata: impl Read, timestamp: SystemTime, mode: u32, compression: Compression, ) -> Result<()>

Adds an entry to the phar.

The file contents shall be later passed with the Contents::feed method in the same order.

pub fn contents(self) -> Result<Contents<W>>

Starts writing the contents section of the phar.

Users should call feed on the returned Contents value with the file contents in the exact same order as entries declared with entry.

pub fn build_from_directory( self, path: &Path, compression: Compression, ) -> Result<()>

Builds the phar from a directory on the filesystem.

pub fn build_from_path_iter<S, P, I>( self, iter: impl Fn() -> I, compression: Compression, ) -> Result<()>
where I: Iterator<Item = Result<(S, P)>>, S: AsRef<OsStr>, P: AsRef<Path>,

Builds the phar from an iterator of file paths.

The iterator parameter yields (S, P) pairs, where each S is an OsStr representing the path inside the archive and each P is a Path that resolves to the actual file to include (at least relative to the current working directory).