pub struct Contents<W: Read + Write + Seek> { /* private fields */ }Available on crate feature
writer only.Expand description
Step for writing phar file contents.
See also the documentation of NeedEntries.
The file signature is automatically appended when all files have been written. File state is undefined before the last entry is written.
Implementations